Interface: ChartTypeRegistry | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ChartTypeRegistry

## # Properties

### # bar

• bar: `Object`

#### # Type declaration

Name | Type
--- | ---
`chartOptions` | `BarControllerChartOptions`
`datasetOptions` | `BarControllerDatasetOptions`
`defaultDataPoint` | `number`
`metaExtensions` | `Object`
`parsedDataType` | `BarParsedData`
`scales` | keyof `CartesianScaleTypeRegistry`

#### # Defined in

index.esm.d.ts:3549
(opens new window)

### # bubble

• bubble: `Object`

#### # Type declaration

Name | Type
--- | ---
`chartOptions` | `unknown`
`datasetOptions` | `BubbleControllerDatasetOptions`
`defaultDataPoint` | `BubbleDataPoint`
`metaExtensions` | `Object`
`parsedDataType` | `BubbleParsedData`
`scales` | keyof `CartesianScaleTypeRegistry`

#### # Defined in

index.esm.d.ts:3573
(opens new window)

### # doughnut

• doughnut: `Object`

#### # Type declaration

Name | Type
--- | ---
`chartOptions` | `DoughnutControllerChartOptions`
`datasetOptions` | `DoughnutControllerDatasetOptions`
`defaultDataPoint` | `number`
`metaExtensions` | `DoughnutMetaExtensions`
`parsedDataType` | `number`
`scales` | keyof `CartesianScaleTypeRegistry`

#### # Defined in

index.esm.d.ts:3589
(opens new window)

### # line

• line: `Object`

#### # Type declaration

Name | Type
--- | ---
`chartOptions` | `LineControllerChartOptions`
`datasetOptions` | `LineControllerDatasetOptions` & `FillerControllerDatasetOptions`
`defaultDataPoint` | `number` | `ScatterDataPoint`
`metaExtensions` | `Object`
`parsedDataType` | `CartesianParsedData`
`scales` | keyof `CartesianScaleTypeRegistry`

#### # Defined in

index.esm.d.ts:3557
(opens new window)

### # pie

• pie: `Object`

#### # Type declaration

Name | Type
--- | ---
`chartOptions` | `DoughnutControllerChartOptions`
`datasetOptions` | `DoughnutControllerDatasetOptions`
`defaultDataPoint` | `number`
`metaExtensions` | `DoughnutMetaExtensions`
`parsedDataType` | `number`
`scales` | keyof `CartesianScaleTypeRegistry`

#### # Defined in

index.esm.d.ts:3581
(opens new window)

### # polarArea

• polarArea: `Object`

#### # Type declaration

Name | Type
--- | ---
`chartOptions` | `PolarAreaControllerChartOptions`
`datasetOptions` | `PolarAreaControllerDatasetOptions`
`defaultDataPoint` | `number`
`metaExtensions` | `Object`
`parsedDataType` | `RadialParsedData`
`scales` | `"radialLinear"`

#### # Defined in

index.esm.d.ts:3597
(opens new window)

### # radar

• radar: `Object`

#### # Type declaration

Name | Type
--- | ---
`chartOptions` | `LineControllerChartOptions`
`datasetOptions` | `RadarControllerDatasetOptions` & `FillerControllerDatasetOptions`
`defaultDataPoint` | `number`
`metaExtensions` | `Object`
`parsedDataType` | `RadialParsedData`
`scales` | `"radialLinear"`

#### # Defined in

index.esm.d.ts:3605
(opens new window)

### # scatter

• scatter: `Object`

#### # Type declaration

Name | Type
--- | ---
`chartOptions` | `LineControllerChartOptions`
`datasetOptions` | `LineControllerDatasetOptions`
`defaultDataPoint` | `number` | `ScatterDataPoint`
`metaExtensions` | `Object`
`parsedDataType` | `CartesianParsedData`
`scales` | keyof `CartesianScaleTypeRegistry`

#### # Defined in

index.esm.d.ts:3565
(opens new window)